@@ -6,8 +6,8 @@ Created on 05-Sep-2019
 
 WILLIAM_K_UL = -75
 WILLIAM_K_LL = -25
-fundamental_info_cols = ['EarningYield', 'FCFYield', 'ROC', 'BookToMkt', 'DivYield',
-                          'Yahoo 1 yr target', 'Intrinsic Value']
+fundamental_info_cols = ['EarningYield', 'FCFYield', 'ROC', 'BookToMkt', 'DivYield', 'EPS Growth Rate',
+                          'EPS', 'Yahoo 1 yr target', 'Intrinsic Value']
 
 STOCK_DETAIL_MODEL_KEY_MAP = {
   'Sector'                                          : 'sector',
@@ -66,7 +66,9 @@ STOCK_DETAIL_MODEL_KEY_MAP = {
   'ROC'                                             : 'roc',
   'EarningYield'                                    : 'earning_yield',
   'FCFYield'                                        : 'fcf_yield',
-  'DivYield'                                        : 'div_yield'}
+  'DivYield'                                        : 'div_yield',
+  'Yahoo 1 yr target'                               : 'yahoo_target_price',
+  'Intrinsic Value'                                 : 'intrinsic_value',}
 
 STOCK_LIST = [
 {'sector' : 'Mining', 'stock' : '20MICRONS'},
